@@ -3,7 +3,7 @@ package DateTime::Fiction::JRRTolkien::Shire;
 use vars qw($VERSION);
 use strict;
 use DateTime;
-our $VERSION = '0.02_01';
+our $VERSION = '0.900_04';
 
 # This assumes all the values in the info hashref are valid, and doesn't do validation
 # However, the day and month parameters will be given defaults if not present
@@ -644,7 +644,7 @@ sub on_date {
 		   28 => "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n"
 		   };
     $events{4} = { 6  => "The mallorn tree flowers in the party field, 1420.\n",
-	           8  => "Ring bearers are honored on the fields of Cormallen, 1419.\n",
+	           8  => "Ring bearers are honored on the Field of Cormallen, 1419.\n",
 	           12 => "Gandalf arrives in Hobbiton, 1418\n"
 	           };
     $events{5} = { 1  => "Crowning of King Elessar, 1419.\n" .
